@@ -6,7 +6,7 @@
 #include <iostream>
 
 CClickFilter::CClickFilter(Dasher::CEventHandler * pEventHandler, CSettingsStore *pSettingsStore, CDasherInterfaceBase *pInterface)
-  : CInputFilter(pEventHandler, pSettingsStore, pInterface, 7, 1, "Click Mode") {
+  : CInputFilter(pEventHandler, pSettingsStore, pInterface, 7, 1, _("Click Mode")) {
   pDasherView = 0;
 }
 
@@ -17,13 +17,13 @@ bool CClickFilter::DecorateView(CDasherView *pView) {
   return false;
 }
 
-bool CClickFilter::Timer(int Time, CDasherView *m_pDasherView, CDasherModel *m_pDasherModel) {
+bool CClickFilter::Timer(int Time, CDasherView *m_pDasherView, CDasherModel *m_pDasherModel, Dasher::VECTOR_SYMBOL_PROB *pAdded, int *pNumDeleted) {
   // FIXME - REALLY, REALLY horrible - bleh
   pDasherView = m_pDasherView;
-  return m_pDasherModel->Tap_on_display(0, 0, Time, 0, 0);
+  return m_pDasherModel->UpdatePosition(0, 0, Time, pAdded, pNumDeleted);
 }
 
-void CClickFilter::KeyDown(int iTime, int iId, CDasherModel *pModel) {
+void CClickFilter::KeyDown(int iTime, int iId, CDasherModel *pModel, CUserLogBase *pUserLog) {
 
   switch(iId) {
   case 100: // Mouse clicks
@@ -31,7 +31,7 @@ void CClickFilter::KeyDown(int iTime, int iId, CDasherModel *pModel) {
       myint iDasherX;
       myint iDasherY;
       
-      pDasherView->TapOnDisplay(0, 0, iTime, iDasherX, iDasherY);
+      pDasherView->GetCoordinates(iTime, iDasherX, iDasherY);
       pModel->ScheduleZoom(iDasherX,iDasherY);
     }
     break;
