@@ -42,7 +42,7 @@ using namespace std;
 
 // Track memory leaks on Windows to the line that new'd the memory
 #ifdef _WIN32
-#ifdef _DEBUG
+#ifdef _DEBUG_MEMLEAKS
 #define DEBUG_NEW new( _NORMAL_BLOCK, THIS_FILE, __LINE__ )
 #define new DEBUG_NEW
 #undef THIS_FILE
@@ -70,15 +70,10 @@ CDasherModel::CDasherModel(CEventHandler *pEventHandler, CSettingsStore *pSettin
 
   m_Rootmin = 0;
   m_Rootmax = 0;
-  m_Rootmin_min = 0;
-  m_Rootmax_max = 0;
-  m_dAddProb = 0.0;
-  m_dMaxRate = 0.0;
   m_iTargetOffset = 0;
   m_dTotalNats = 0.0;
  
   // TODO: Need to rationalise the require conversion methods
-
 #ifdef JAPANESE
   m_bRequireConversion = true;
 #else
@@ -96,14 +91,6 @@ CDasherModel::CDasherModel(CEventHandler *pEventHandler, CSettingsStore *pSettin
   m_Rootmin_min = int64_min / iNormalization / 2;
   m_Rootmax_max = int64_max / iNormalization / 2;
 
-  //  m_pLanguageModel = m_pNodeCreationManager->GetLanguageModel();
-  //  LearnContext = m_pNodeCreationManager->GetLearnContext();
-
-  //  m_bContextSensitive = true;
-
-  // TODO: Do something sensible here
-  //  Start();
-
   InitialiseAtOffset(iOffset, pView);
 }
 
@@ -164,6 +151,9 @@ void CDasherModel::HandleEvent(Dasher::CEvent *pEvent) {
 }
 
 void CDasherModel::Make_root(CDasherNode *pNewRoot) {
+  // TODO: Note that subnodes can be the root transiently during the
+  // re-rooting process.
+
   DASHER_ASSERT(pNewRoot != NULL);
   DASHER_ASSERT(pNewRoot->NodeIsParent(m_Root));
 
@@ -173,35 +163,19 @@ void CDasherModel::Make_root(CDasherNode *pNewRoot) {
   // existing data structure?
   oldroots.push_back(m_Root);
 
-  // Clear roots...
-  // First figure out how many we can get rid of
+  // TODO: tidy up conditional
+  while(((oldroots.size() > 10) && (!m_bRequireConversion || (oldroots[0]->GetFlag(NF_CONVERTED)))) || 
+	(oldroots[0]->GetFlag(NF_SUBNODE))) {
+    oldroots[0]->OrphanChild(oldroots[1]);
+    delete oldroots[0];
+    oldroots.pop_front();
+  }
 
-  int iOldRootSize(oldroots.size());
-  int iMaxHead(iOldRootSize - 10);
+//   for(int i(0); i < oldroots.size(); ++i)
+//     std::cout << oldroots[i]->GetFlag(NF_SUBNODE) << " ";
+
+//  std::cout << std::endl;
   
-  int iMinHead(0);
-
-  for(int i(1); i <= iMaxHead; ++i) {
-    if((!m_bRequireConversion || (oldroots[i]->GetFlag(NF_CONVERTED))) &&
-       !(oldroots[i]->GetFlag(NF_SUBNODE)))
-      iMinHead = i;
-  }
-    
-  if(iMinHead > 0) {
-    for(int i(0); i < iMinHead; ++i) {
-      oldroots[0]->OrphanChild(oldroots[1]);
-      delete oldroots[0];
-      oldroots.pop_front();
-    }
-  }
-    
-
-//   while((oldroots.size() > 10) && (!m_bRequireConversion || (oldroots[0]->GetFlag(NF_CONVERTED)))) {
-//     oldroots[0]->OrphanChild(oldroots[1]);
-//     delete oldroots[0];
-//     oldroots.pop_front();
-//   }
-
   m_Root = pNewRoot;
 
   // Update the root coordinates, as well as any currently scheduled locations
@@ -257,6 +231,8 @@ void CDasherModel::Reparent_root(int lower, int upper) {
   CDasherNode *pNewRoot;
 
   if(oldroots.size() == 0) {
+    //    std::cout << "a" << std::endl;
+
     // No nodes in the stack, so make a new one
 
     // TODO: iGenerations is redundant, get rid of it
@@ -265,21 +241,35 @@ void CDasherModel::Reparent_root(int lower, int upper) {
 
   }
   else {
+    //    std::cout << "b" << std::endl;
+
+    //    for(int i(0); i < oldroots.size(); ++i)
+    //      std::cout << oldroots[i]->GetFlag(NF_SUBNODE) << " ";
+    
+    //   std::cout << std::endl;
+
     pNewRoot = oldroots.back();
     oldroots.pop_back();
 
-    DASHER_ASSERT(!((oldroots.front())->GetFlag(NF_SUBNODE)));
-
     while((oldroots.size() > 0) && pNewRoot->GetFlag(NF_SUBNODE)) {
       pNewRoot = oldroots.back();
       oldroots.pop_back();
     }
+
+    //    for(int i(0); i < oldroots.size(); ++i)
+    // std::cout << oldroots[i]->GetFlag(NF_SUBNODE) << " ";
+    
+    //std::cout << std::endl;
+    
+    // std::cout << "---" << std::endl;
   }
 
   // Return if there's no existing parent and no way of recreating one
   if(pNewRoot == NULL)
     return;
 
+  DASHER_ASSERT(!(pNewRoot->GetFlag(NF_SUBNODE)));
+
   pNewRoot->SetFlag(NF_COMMITTED, false);
 
   CDasherNode *pCurrent = m_Root;
@@ -382,6 +372,7 @@ void CDasherModel::InitialiseAtOffset(int iOffset, CDasherView *pView) {
   // size and we're not in any of the children
 
   double dFraction( 1 - (1 - m_Root->MostProbableChild() / static_cast<double>(GetLongParameter(LP_NORMALIZATION))) / 2.0 );
+
   int iWidth( static_cast<int>( (GetLongParameter(LP_MAX_Y) / (2.0*dFraction)) ) );
 
   m_Rootmin = GetLongParameter(LP_MAX_Y) / 2 - iWidth / 2;
@@ -491,6 +482,10 @@ bool CDasherModel::UpdatePosition(myint miMousex, myint miMousey, unsigned long
   if(GetBoolParameter(BP_DASHER_PAUSED) && (m_deGotoQueue.size() == 0))
      return false;
 
+  // Find out the current node under the crosshair
+  CDasherNode *old_under_cross=Get_node_under_crosshair();
+
+
   myint iNewMin;
   myint iNewMax;
 
@@ -512,6 +507,17 @@ bool CDasherModel::UpdatePosition(myint miMousex, myint miMousey, unsigned long
   // Now actually zoom to the new location
   NewGoTo(iNewMin, iNewMax, pAdded, pNumDeleted);
 
+
+  // Check whether new nodes need to be created
+  CDasherNode* new_under_cross = Get_node_under_crosshair();
+  Push_Node(new_under_cross);
+  
+  // TODO: Make this more efficient
+  new_under_cross = Get_node_under_crosshair();
+
+  HandleOutput(new_under_cross, old_under_cross, pAdded, pNumDeleted);
+
+
   return true;
 }
 
@@ -520,6 +526,8 @@ void CDasherModel::NewFrame(unsigned long Time) {
 }
 
 void CDasherModel::OldPush(myint iMousex, myint iMousey) {
+  std::cout << "Old Push" << std::endl;
+
   // push node under mouse
   CDasherNode *pUnderMouse = Get_node_under_mouse(iMousex, iMousey);
 
@@ -588,8 +596,6 @@ void CDasherModel::RecursiveOutput(CDasherNode *pNode, Dasher::VECTOR_SYMBOL_PRO
 }
 
 void CDasherModel::NewGoTo(myint newRootmin, myint newRootmax, Dasher::VECTOR_SYMBOL_PROB* pAdded, int* pNumDeleted) {
-  // Find out the current node under the crosshair
-  CDasherNode *old_under_cross=Get_node_under_crosshair();
 
   // Update the max and min of the root node to make iTargetMin and
   // iTargetMax the edges of the viewport.
@@ -622,51 +628,72 @@ void CDasherModel::NewGoTo(myint newRootmin, myint newRootmax, Dasher::VECTOR_SY
     // TODO - force a new root to be chosen, so that we get better
     // behaviour than just having Dasher stop at this point.
   }
-
-  // Check whether new nodes need to be created
-  CDasherNode* new_under_cross = Get_node_under_crosshair();
-  Push_Node(new_under_cross);
-
-  HandleOutput(new_under_cross, old_under_cross, pAdded, pNumDeleted);
 }
 
 void CDasherModel::HandleOutput(CDasherNode *pNewNode, CDasherNode *pOldNode, Dasher::VECTOR_SYMBOL_PROB* pAdded, int* pNumDeleted) {
   DASHER_ASSERT(pNewNode != NULL);
   //  DASHER_ASSERT(pOldNode != NULL);
   
+//   if(pNewNode != pOldNode)
+//     std::cout << "HandleOutput: " << pOldNode << " => " << pNewNode << std::endl;
+
   if(pNewNode != m_pLastOutput)
     DeleteCharacters(pNewNode, m_pLastOutput, pNumDeleted);
   
-  m_pLastOutput = pNewNode;
-
-  if(pNewNode->GetFlag(NF_SEEN))
+  if(pNewNode->GetFlag(NF_SEEN)) {
+    m_pLastOutput = pNewNode;
     return;
+  }
 
   RecursiveOutput(pNewNode, pAdded);
+
+  m_pLastOutput = pNewNode;
 }
 
 bool CDasherModel::DeleteCharacters(CDasherNode *newnode, CDasherNode *oldnode, int* pNumDeleted) {
   DASHER_ASSERT(newnode != NULL);
   DASHER_ASSERT(oldnode != NULL);
 
+  //  std::cout << oldnode << " " << newnode << std::endl;
+
   // This deals with the trivial instance - we're reversing back over
   // text that we've seen already
   if(newnode->GetFlag(NF_SEEN)) {
+    // TODO: I really cannot believe that  the following could ever have worked.
+    
+  //   if(oldnode->Parent() == newnode) {
+//       std::cout << "DCA" << std::endl;
+//       oldnode->m_pNodeManager->Undo(oldnode);
+//       oldnode->Parent()->m_pNodeManager->Enter(oldnode->Parent());
+//       if (pNumDeleted != NULL)
+//         (*pNumDeleted)++;
+//       oldnode->SetFlag(NF_SEEN, false);
+//       return true;
+//     }
+//     if(DeleteCharacters(newnode, oldnode->Parent(), pNumDeleted) == true) {
+//       std::cout << "DCB" << std::endl;
+//       oldnode->m_pNodeManager->Undo(oldnode);
+//       oldnode->Parent()->m_pNodeManager->Enter(oldnode->Parent());
+//       if (pNumDeleted != NULL)
+// 	(*pNumDeleted)++;
+//       oldnode->SetFlag(NF_SEEN, false);
+//       return true;
+//     }
+
     oldnode->m_pNodeManager->Undo(oldnode);
     oldnode->Parent()->m_pNodeManager->Enter(oldnode->Parent());
-
-    // TODO: This is completely the wrong place to trap output
-    if(pNumDeleted != NULL)
-      (*pNumDeleted) += oldnode->m_iNumSymbols;
-
+    if (pNumDeleted != NULL)
+      (*pNumDeleted)++;
     oldnode->SetFlag(NF_SEEN, false);
 
     if(oldnode->Parent() != newnode)
       DeleteCharacters(newnode, oldnode->Parent(), pNumDeleted);
 
     return true;
+
   }
   else {
+    //    std::cout << "DCC" << std::endl;
     // This one's more complicated - the user may have moved onto a new branch
     // Find the last seen node on the new branch
     CDasherNode *lastseen = newnode->Parent();
@@ -685,8 +712,7 @@ bool CDasherModel::DeleteCharacters(CDasherNode *newnode, CDasherNode *oldnode,
 	oldnode->Parent()->m_pNodeManager->Enter(oldnode->Parent());
 
       if (pNumDeleted != NULL)
-	(*pNumDeleted) += oldnode->m_iNumSymbols;
-
+	(*pNumDeleted)++;
       oldnode = oldnode->Parent();
       if(oldnode == NULL) {
         return false;
@@ -745,6 +771,8 @@ bool CDasherModel::RenderToView(CDasherView *pView, bool bRedrawDisplay) {
   DASHER_ASSERT(pView != NULL);
   DASHER_ASSERT(m_Root != NULL);
 
+  CDasherNode *pOldNode = Get_node_under_crosshair();
+
   std::vector<CDasherNode *> vNodeList;
   std::vector<CDasherNode *> vDeleteList;
 
@@ -763,6 +791,13 @@ bool CDasherModel::RenderToView(CDasherView *pView, bool bRedrawDisplay) {
       (*it)->Delete_children();
   }
 
+  CDasherNode *pNewNode = Get_node_under_crosshair();
+
+  // TODO: Fix up stats
+  // TODO: Is this the right way to handle this?
+  if(pNewNode != pOldNode)
+    HandleOutput(pNewNode, pOldNode, NULL, NULL);
+
   return bReturnValue;
 }
 
@@ -795,6 +830,8 @@ bool CDasherModel::CheckForNewRoot(CDasherView *pView) {
   DASHER_ASSERT(m_Root != NULL);
   // TODO: pView is redundant here
 
+  CDasherNode *pOldNode = Get_node_under_crosshair();
+
   CDasherNode *root(m_Root);
   CDasherNode::ChildMap & children = m_Root->Children();
 
@@ -804,6 +841,8 @@ bool CDasherModel::CheckForNewRoot(CDasherView *pView) {
     return(m_Root != root);
   }
 
+  DASHER_ASSERT(!(m_Root->GetFlag(NF_SUBNODE)));
+
   CDasherNode *pNewRoot = NULL;
 
   bool bFound = false;
@@ -811,10 +850,19 @@ bool CDasherModel::CheckForNewRoot(CDasherView *pView) {
   if(RecursiveCheckRoot(m_Root, &pNewRoot, bFound)) {
     if(bFound) { // TODO: I think this if statement is reduncdent, return value of above is always equal to bFound
       m_Root->DeleteNephews(pNewRoot);
+      //      std::cout << "m..." << std::endl;
       RecursiveMakeRoot(pNewRoot);
+      //std::cout << "...m" << std::endl;
     }
   }
 
+  CDasherNode *pNewNode = Get_node_under_crosshair();
+
+  // TODO: Fix this, make more efficient
+  // TODO: Unnecessary? Should never change anuything
+  if(pNewNode != pOldNode)
+    HandleOutput(pNewNode, pOldNode, NULL, NULL);
+
   DASHER_ASSERT(!(m_Root->GetFlag(NF_SUBNODE)));
   return false;
 }
