@@ -20,7 +20,7 @@ using namespace Dasher;
 
 // Track memory leaks on Windows to the line that new'd the memory
 #ifdef _WIN32
-#ifdef _DEBUG
+#ifdef _DEBUG_MEMLEAKS
 #define DEBUG_NEW new( _NORMAL_BLOCK, THIS_FILE, __LINE__ )
 #define new DEBUG_NEW
 #undef THIS_FILE
@@ -147,6 +147,8 @@ void CDasherView::DasherPolygon(myint *x, myint *y, int n, int iColour) {
 
 void CDasherView::DasherDrawRectangle(myint iLeft, myint iTop, myint iRight, myint iBottom, const int Color, int iOutlineColour, Opts::ColorSchemes ColorScheme, bool bDrawOutline, bool bFill, int iThickness) {
 
+  //  std::cout << "Drawing rectangle: (" << iLeft << ", " << iTop << ") - (" << iRight << ", " << iBottom << ")" << std::endl;
+
   screenint iScreenLeft;
   screenint iScreenTop;
   screenint iScreenRight;
