@@ -19,6 +19,10 @@ namespace Dasher {
   class CLanguageModel;
 }
 
+///
+/// \defgroup LM Language modelling
+/// @{
+
 ///
 /// \brief Language model base class
 /// Base class for all language model components
@@ -94,7 +98,7 @@ public:
   /// Get symbol probability distribution
   /// 
 
-  virtual void GetProbs(Context Context, std::vector < unsigned int >&Probs, int iNorm) const = 0;
+  virtual void GetProbs(Context Context, std::vector < unsigned int >&Probs, int iNorm, int iUniform) const = 0;
 
   /// @}
 
@@ -137,7 +141,33 @@ public:
 
   /// @}
 
+  ///
+  /// Get the maximum useful context length for this language model
+
+  virtual int GetContextLength() const {
+    // TODO: Fix hard coded value
+    return 5;
+  };
+
  protected:
+  struct SLMFileHeader {
+    // Magic number ("%DLF" in ASCII)
+    char szMagic[4];
+    // Version of the header
+    unsigned short int iHeaderVersion;
+    // Total size of header (including variable length alphabet name)
+    unsigned short int iHeaderSize;
+    // ID of the language model
+    unsigned short int iLMID;
+    // Version number of the language model
+    unsigned short int iLMVersion;
+    // Minimum compatible version for the language model
+    unsigned short int iLMMinVersion;
+    // Number of characters in the alphabet
+    unsigned short int iAlphabetSize;
+    // UTF-8 encoded alphabet name follows (variable length struct)
+  };
+
   int GetSize() const {
     return m_Alphabet.GetSize();
   }
@@ -149,6 +179,8 @@ public:
 
 };
 
+/// @}
+
 /////////////////////////////////////////////////////////////////////////////
 
 #endif // ndef __LanguageModelling_LanguageModel_h__
