@@ -45,8 +45,12 @@ void CDasher::CreateLocalFactories() {
 }
 
 void CDasher::Main() {
-	if(m_pCanvas)
+  if(m_pCanvas) {
 		m_pCanvas->DoFrame();
+  }
+
+  DWORD dwTicks = GetTickCount();
+	NewFrame(dwTicks, false);
 }
 
 // Handles the work we need to do periodically on a timer event
@@ -117,34 +121,36 @@ void Dasher::CDasher::SetEdit(CDashEditbox * pEdit) {
 }
 
 void Dasher::CDasher::WriteTrainFile(const std::string &strNewText) {
-  const std::string TrainFile = GetStringParameter(SP_USER_LOC) + GetStringParameter(SP_TRAIN_FILE);
-
-  if(strNewText.size() == 0)
+  // TODO: Reimplement
+  // FIXME - use parameter
+//  const string & TrainFile = GetStringParameter(SP_USER_LOC) + GetTrainFile();
+//  if(TrainFile == "")
     return;
 
-  Tstring TTrainFile;
-  UTF8string_to_wstring(TrainFile, TTrainFile);
+  //if(strNewText == "")
+  //  return;
 
-  HANDLE hFile = CreateFile(TTrainFile.c_str(),
-                            GENERIC_WRITE, 0, NULL, 
-                            OPEN_ALWAYS, 
-                            FILE_ATTRIBUTE_NORMAL, 0);
+  //Tstring TTrainFile;
+  //UTF8string_to_wstring(TrainFile, TTrainFile);
 
-  if(hFile == INVALID_HANDLE_VALUE) {
-    OutputDebugString(TEXT("Can not open file\n"));
-  }
-  else {
-    DWORD NumberOfBytesWritten;
-    SetFilePointer(hFile, 0, NULL, FILE_END);
+  //HANDLE hFile = CreateFile(TTrainFile.c_str(),
+  //                          GENERIC_WRITE, 0, NULL, OPEN_ALWAYS, FILE_ATTRIBUTE_NORMAL, 0);
+
+  //if(hFile == INVALID_HANDLE_VALUE) {
+  //  OutputDebugString(TEXT("Can not open file\n"));
+  //}
+  //else {
+  //  DWORD NumberOfBytesWritten;
+  //  SetFilePointer(hFile, 0, NULL, FILE_END);
 
   //// Surely there are better ways to write to files than this??
 
-    for(unsigned int i = 0; i < strNewText.size(); i++) {
-      WriteFile(hFile, &strNewText[i], 1, &NumberOfBytesWritten, NULL);
-    }
+  //  for(unsigned int i = 0; i < strNewText.size(); i++) {
+  //    WriteFile(hFile, &strNewText[i], 1, &NumberOfBytesWritten, NULL);
+  //  }
 
-    CloseHandle(hFile);
-  }
+  //     CloseHandle(hFile);
+  //}
 }
 
 void CDasher::ScanDirectory(const Tstring &strMask, std::vector<std::string> &vFileList) {
@@ -255,8 +261,3 @@ void CDasher::StartTimer() {
 void CDasher::ShutdownTimer() {
 }
 
-void CDasher::Layout(int iX, int iY, int iWidth, int iHeight) {
-  if(m_pCanvas)
-    m_pCanvas->Move(iX, iY, iWidth, iHeight);
-}
-
